function get_stream_data(L)
% Get stream data
%
% Author: DJ van Gerwen
% Created: 2016 june 5



% Request twice the number of scans expected, to be sure you get everything,
% and size the data matrix to hold the corresponding number of samples
number_of_scans_requested = 2 * L.expected_scans_per_chunk;
number_of_samples_requested = ...
    number_of_scans_requested * L.number_of_stream_channels;

% Init array to store data
chunk = NET.createArray('System.Double', number_of_samples_requested);
% NOTE: This needs to be a system.double, because the eGetPtr() function and
% the eStreamRead() function use pass-by-reference to change the value of chunk.
% This is rather unmatlabby...

if ismember(L.device_type, {'U3', 'UE9'})
    
    % Read streamed data chunk
    [L.last_error, number_of_scans_returned] = ...
        L.UDobject.eGetPtr(L.lj_handle, LabJack.LabJackUD.IO.GET_STREAM_DATA,...
        LabJack.LabJackUD.CHANNEL.ALL_CHANNELS, number_of_scans_requested, chunk);
    
elseif strcmp(L.device_type, 'T7')
    
    % Read streamed data chunk
    [L.last_error, L.backlog_device(end+1), L.backlog_driver(end+1)] = ...
        LabJack.LJM.eStreamRead(L.lj_handle, chunk, 0, 0);
    samples_skipped = sum(double(chunk) == -9999);
    if samples_skipped
        warning('%u samples were skipped...',samples_skipped)
    end
    %number_of_scans_returned = number_of_samples_requested/L.number_of_AIN; % Q&D...
end

% Select only the actual returned samples
chunk = double(chunk); % Convert the System.Double object to a matlab array
number_of_samples_returned = find(chunk~=0, 1, 'last');
L.chunk_data = chunk(1:number_of_samples_returned); % Update chunk data
L.chunk_size = [L.chunk_size, number_of_samples_returned];

%             number_of_samples_returned = L.number_of_AIN*number_of_scans_returned;
%             chunk = double(chunk); % Convert the System.Double object to a matlab array
%             L.chunk_data = chunk(1:number_of_samples_returned); % Update chunk data
%             L.chunk_size = [L.chunk_size, number_of_samples_returned];

% Broadcast event
notify(L, 'DataAvailable')

end % Get stream data