function start_stream(L)

% Start LabJack stream
%
% Author: DJ van Gerwen
% Created: 2016 june 5

% Initialize timer
L.timer_handle = timer(...
    'executionmode','fixedrate',...
    'busymode','drop',...
    'period',L.chunk_time_s,...
    'startdelay',L.chunk_time_s,... % Necessary to allow labjack stream to fill
    'taskstoexecute',inf);

% Set timer callbacks (NOTE: these need to be static functions, otherwise the LJ object will not be deleted properly)
set(L.timer_handle,'timerfcn',{@LJ.timerfcn,L});

% Start the stream.
if ~L.is_running()
    if ismember(L.device_type,{'U3','UE9'})
        [~, L.scan_rate_achieved_Hz] = L.UDobject.eGet(L.lj_handle,...
            LabJack.LabJackUD.IO.START_STREAM, 0, 0, 0);
    elseif strcmp(L.device_type,'T7')
        AINlist = 2*L.AIN_list; % Address for channel AINi is 2*i (see http://labjack.com/support/modbus/map)
        [L.last_error, L.scan_rate_achieved_Hz] = LabJack.LJM.eStreamStart(...
            L.lj_handle, L.chunk_time_s*L.scan_rate_requested_Hz,...
            L.number_of_AIN, AINlist, L.scan_rate_requested_Hz); % chunk_time*scan_rate=expected_scans_per_chunk, or "scans per read" in labjack terminology
    end
    
    % Actual scan rate depends on how the requested scan rate divides into the LabJack clock.
    L.stream_rate_achieved_Hz = L.scan_rate_achieved_Hz * L.number_of_AIN;
    fprintf(1,'Stream started (actual scan rate %uHz, actual stream rate %uHz)\n',L.scan_rate_achieved_Hz,L.stream_rate_achieved_Hz);
else
    disp('Stream already started')
end

% Start timer
start(L.timer_handle)

% Flag
L.stream_started = 1;

end
