function timerfcn(~, ~, L)

% This function is called in a (quasi-)asynchronous loop by a matlab timer object.
% Stream data from the labjack is retrieved at a fixed rate or fixed
% interval depending on timer settings.
%
% Author: DJ van Gerwen
% Created: 2016 june 5


% Get chunk data and append to history
L.get_stream_data() % Updates the chunk_data property
if length(L.stream_data_V) == L.stream_data_maxlength
    fprintf(1, 'Stream data truncated at %u samples', L.stream_data_maxlength);
end
L.stream_data_V = ...
    [L.stream_data_V(max(1,end-L.stream_data_maxlength+1):end),...
    L.chunk_data];


if L.show_backlogs % TODO: adapt to LJM for T7
    
    if ismember(L.device_type, {'U3', 'UE9'})
        % Retrieve the current backlog.  The UD driver retrieves stream data from
        % the U3 in the background, but if the computer is too slow for some reason
        % the driver might not be able to read the data as fast as the U3 is
        % acquiring it, and thus there will be data left over in the U3 buffer.
        [L.last_error, backlog.control] = ...
            L.UDobject.eGet(L.lj_handle, LabJack.LabJackUD.IO.GET_CONFIG, ...
            LabJack.LabJackUD.CHANNEL.STREAM_BACKLOG_CONTROL, 0, 0);
        [L.last_error, backlog.comm] = ...
            L.UDobject.eGet(L.lj_handle, LabJack.LabJackUD.IO.GET_CONFIG, ...
            LabJack.LabJackUD.CHANNEL.STREAM_BACKLOG_COMM, 0, 0);
        [L.last_error, backlog.driver] = ...
            L.UDobject.eGet(L.lj_handle, LabJack.LabJackUD.IO.GET_CONFIG, ...
            LabJack.LabJackUD.CHANNEL.STREAM_BACKLOG_UD, 0, 0);
    elseif strcmp(L.device_type,'T7')
        % TODO... backlogs are returned in the get_stream_data function, so just need to get them here.
    end
    
    % Display backlog
    fprintf(1, repmat('\b', 1, length(L.backlog_string)));
    L.backlog_string = sprintf('\tBacklogs:\n\tCONTROL: %u, COMM: %u, DRIVER: %u\n', ...
        backlog.control, backlog.comm, backlog.driver);
    fprintf(1, '%s', L.backlog_string);
end

end