function toggle_relay(L)
% TOGGLE (SOLID STATE) RELAYS USING SINKING CONFIGURATION
% i.e. relay+ connected to Vs, relay- connected to FIOi, and
% switching is done by reconfiguring FIOi, either as output low
% (equivalent of ground) which turns on the relay, or as input
% (equivalent of 3.3V, with additional voltage drop due to internal
% resistor, so that total voltage drop is close to 5V) which turns
% off the relay.
% TODO: auto update lists if duplicates in FIO_list and relay_list...
% NOTE: Sinking configuration: connect relay+ to labjack Vs, relay- to labjack FIO0
%
% Author: DJ van Gerwen
% Created: 2016 june 5


for i = 1:length(L.relay_list)
    FIOi = L.relay_list(i);
    if ~ismember(FIOi, L.FIO_list)
        if ismember(L.device_type,{'U3','UE9'})
            if L.relay_state(i)
                % Set FIOi to output low (relay gets 5V)
                L.UDobject.eGet(L.lj_handle,...
                    LabJack.LabJackUD.IO.PUT_DIGITAL_BIT,FIOi,0,0);
                fprintf('FIO%u relay on\n',FIOi);
            else
                % Set FIOi to input (relay gets 0V)
                [~,~] = L.UDobject.eGet(L.lj_handle,...
                    LabJack.LabJackUD.IO.GET_DIGITAL_BIT,FIOi,0,0);
                fprintf('FIO%u relay off\n',FIOi);
            end
        elseif strcmp(L.device_type,'T7')
            if L.relay_state(i)
                % Set FIOi to output low (relay gets 5V)
                LabJack.LJM.eWriteName(L.lj_handle,sprintf('FIO%u',FIOi),0);
                fprintf('FIO%u relay on\n',FIOi);
            else
                % Set FIOi to input (relay gets 0V)
                [~,~] = LabJack.LJM.eReadName(L.lj_handle,sprintf('FIO%u',FIOi),0);
                fprintf('FIO%u relay off\n',FIOi);
            end
        end
    else
        warning('Cannot enable FIO%u relay, because FIO%u is already present in the FIO_list.',FIOi,FIOi)
    end
end

end