function [] = PillowMeasure(figGUI)
%% This function acquires data from the LabJack and stores it in data
% that is stored in structure 'h', stored in 'UserData' of object hBOJ.
% h delivers and stores a.o.: h.DataT,h.DataV,h.DataF,h.SampleT,h.Subjnr

% Author: dr.ir. Arjo J. Loeve, ir. Nick van de berg
% E-mail: a.j.loeve@tudelft.nl
% Date: 2016AUG15-17.45

% Measure by getting State Values from LJ
% Add values of V, F (calculated) and T to data matrix
% Keep track of measurement duration
% At each sample check if F is above threshold
% If so, set appropriate message and add F*dT to cumulative 
% If too low, set appropriate message
%
% Refresh plot after each sample

global measflag;
global readflag;

%% EXTRACED FROM PillowExe AS A REFERENCE
% % Make measurement constants and provide CALLIBRATION factors
% % Values were from 2016-08-11 and may not be up to date...be aware
% h.SampleT = 1/500; % Sampletime in ms (approximation because of system delays)...TO BE IMPROVED
% h.SmotherF = 200; % Threshold force required to suffocate [N]
% h.SmotherT = 240*h.SmotherF; % F*T required above threshold force to suffocate
% h.VtoF = [0 100]; % [a b] Callibration factors Volts to Newtons: F=a+b*V
% % Make data variables
% h.Subjnr = '';
% h.DataT = []; % Time stamps
% h.DataT_sum= []; % Total time of test run, excluding pauses
% h.DataT_val = []; % Total time above threshold
% h.DataV = []; % Voltages
% h.DataF = []; % Forces
% Define figure properties for data plotting
% h.PlotLength = 1000; % Nr of samples plotted maximally in figure
% %Global flags available:
% measflag % active measurement going on (0 during pauses)
% readflag % background measurement continuing (1 during pauses)

%% Initiate
SmotherCount = 0; % Count smother impulse above threshold
iPlot = 0;
iPlotSec = 1;
h = get(figGUI,'UserData');
set(figGUI, 'CurrentAxes', h.xesForce)
delete(h.xesForce.Children(:)); % Not necessary when NextPlot='replace'
figF=line(0,0,'LineWidth',4,'Color',h.cssCForce);

%% Get data
% Start timer
T_meas = tic;
while readflag == 1
    pause(h.SampleT);
    h = get(figGUI,'UserData');
    if isempty(h.DataT)
        h.DataT=0;
        h.DataV=0;
        h.DataF=0;
        h.DataP=0;
    end
    h.DataT_run = h.DataT_run+h.SampleT;
    % Keep registering data even during pauses...just for info
    % Variable containing voltage is: h.LJ.AIN_state_V
    newV = h.LJ.AIN_state_V;
    newF = h.VtoF*(ones(2,1)*newV); % Assuming linear. Offset and slope.
    newT = h.DataT(end)+h.SampleT; %toc(Tstart);
    h.DataT = [h.DataT; newT];
    h.DataV = [h.DataV; newV];
    h.DataF = [h.DataF; newF];
    h.DataP = [h.DataP; abs(measflag-1)];
    % Set iPlotMax in samples;
    iPlotMax = iPlotSec/h.SampleT;
    % Detect change of pause from 0 to 1 to count pauses.
    if h.DataP(end)==1 && h.DataP(end-1)~=1
        h.intPauses = h.intPauses+1;
    end
    
    if measflag ==1
        % Check if SmotherCount is full
        % If full, end measurement and adapt message label
        % If not, continue to process data
        if SmotherCount >= h.SmotherT
            % Wrapp up and end measuring
            h.Completed = 1;
            % Set controls statuses
            h.Start.Enable='off';
            h.Start.String='Measurement Completed';
            h.Start.BackgroundColor=h.cssCBackMesDone;
            h.Stop.Enable='off';
            h.Next.Enable='on';
            h.Next.String=h.strNextSave;
            
            % END ROUTINE AND SEND DATA TO PillowExe
            % Tell to stop
            h.lblMes.String = h.MesDone;
            h.lblMes.BackgroundColor = h.cssCBackMesDone; 
            measflag = 0;
            readflag = 0;
        else
            % Add to SmotherCount if F above threshold and don't if not
            % Adapt message banner accordingly
            if newF >= h.SmotherF
                h.DataT_smo=h.DataT_smo+h.SampleT;
                h.DataT_val=h.DataT_val+h.SampleT;
                % Add to SmotherCount
                SmotherCount = SmotherCount +...
                    (newT-h.DataT(end-1))*((h.DataF(end-1)+newF)/2);
                h.SmotherProg = num2str(floor(100*SmotherCount/h.SmotherT));
                % Ask to keep pushing
                h.edtSmotherProg.String=h.SmotherProg;
                h.lblMes.String = h.MesKeep;
                h.lblMes.BackgroundColor = h.cssCBackMesKeep;
            else
                h.DataT_smo=h.DataT_smo+h.SampleT;
                % Ask to push harder
                h.lblMes.String = h.MesHarder;
                h.lblMes.BackgroundColor = h.cssCBackMesHarder;
            end
        end
    else
        % Simply keep registering and showing it, but do not update message
        % or count the force for the total impulse.
        % That way we can check the equipment during pauses.        
    end
    % Update OUT Graph
    DataLength = length(h.DataF);
    
    % For processor speed reasons, plot only every iPlotMax samples
    if iPlot >= iPlotMax
        if DataLength<=h.PlotLength;
            h.xesForce.XLim = [0 h.SampleT*(h.PlotLength-1)];%setting the x axis 
            figF.XData = h.DataT; %0:h.SampleT:h.SampleT*(h.PlotLength-1); %adjusting the x coordinate
            figF.YData = h.DataF; %adjusting the y coordinate 
            drawnow
        else            
            h.xesForce.XLim =[h.DataT(end)-h.SampleT*(h.PlotLength-1) h.DataT(end)];%setting the x axis 
            figF.XData = h.DataT(end-h.PlotLength+1:end); %adjusting the x coordinate
            figF.YData = h.DataF(end-h.PlotLength+1:end); %adjusting the y coordinate 
            drawnow
        end  
        iPlot = 0;
    else
        iPlot = iPlot +1;
    end
    % Update OUT text boxes
    h.edtVolt.String = num2str(round(newV,3));
    h.edtForce.String = num2str(round(newF,1));
    % Update timer
    h.DateT_clock = toc(T_meas);
    % Update main user data
    set(figGUI,'UserData',h); % Handles 'h' stored in figure UserData
    
end





